# Update Notes

## version 0.2.1

* Add support for typing.List for python 3.10

## version 0.2.0

* Lazyparser doesn't handle FileType and Function types anymore.

## version 0.1.1

* Fix list subtypes checking when defined in the function definition.
* The object `List` form **typing** package is now recognized by Lazyparser and automatically transformed in ``lazyparser.List`` object.
